@@ -1,26 +1,31 @@
 if __name__ == '__main__':
 
   import sys
+  import multiprocessing
+  multiprocessing.freeze_support()  # documentation mistakenly states this is required only on Windows; it's also required on Mac and does nothing on Linux
+
   import os
-  dir_path = os.path.dirname(os.path.realpath(__file__))
+  import zebrazoom.code.paths as paths
 
   from zebrazoom.code.vars import getGlobalVariables
+  from zebrazoom.GUIAllPy import PlainApplication, ZebraZoomApp
   globalVariables = getGlobalVariables()
 
   if len(sys.argv) == 1:
 
-    print("The data produced by ZebraZoom can be found in the folder: " + os.path.join(dir_path,'ZZoutput'))
-    from zebrazoom.GUIAllPy import ZebraZoomApp
+    print("The data produced by ZebraZoom can be found in the folder: " + paths.getDefaultZZoutputFolder())
     app = ZebraZoomApp(sys.argv)
     sys.exit(app.exec())
 
   else:
 
+    if sys.argv[1] == "selectZZoutput" or sys.argv[1] == "--exit":
+      app = ZebraZoomApp(sys.argv)
+    else:
+      app = PlainApplication(sys.argv)
     if sys.argv[1] == "selectZZoutput":
 
-      print("The data produced by ZebraZoom can be found in the folder: " + os.path.join(dir_path,'ZZoutput'))
-      from zebrazoom.GUIAllPy import ZebraZoomApp
-      app = ZebraZoomApp(sys.argv)
+      print("The data produced by ZebraZoom can be found in the folder: " + paths.getDefaultZZoutputFolder())
       app.askForZZoutputLocation()
       sys.exit(app.exec())
 
@@ -80,7 +85,7 @@ if __name__ == '__main__':
       sqb_convert_to_avi(path, videoName, codec, lastFrame)
       print("small break start")
       time.sleep(2)
-      print("Launching the tracking, the data produced by ZebraZoom can be found in the folder: " + os.path.join(dir_path,'ZZoutput'))
+      print("Launching the tracking, the data produced by ZebraZoom can be found in the folder: " + paths.getDefaultZZoutputFolder())
       __spec__ = "ModuleSpec(name='builtins', loader=<class '_frozen_importlib.BuiltinImporter'>)"
       mainZZ(path2, videoName, 'avi', configFile, argv2)
 
@@ -90,7 +95,7 @@ if __name__ == '__main__':
       from zebrazoom.code.deepLearningFunctions.labellingFunctions import createMask
       pathToImgFolder = sys.argv[2]
       if not(os.path.exists(pathToImgFolder)):
-        pathToImgFolder = os.path.join(os.path.join(os.path.join(dir_path,'ZZoutput'), sys.argv[2]), 'PNGImages')
+        pathToImgFolder = os.path.join(paths.getDefaultZZoutputFolder(), sys.argv[2], 'PNGImages')
       createMask(pathToImgFolder)
 
 
@@ -98,7 +103,7 @@ if __name__ == '__main__':
 
       if sys.argv[2] == "sleepVsMoving":
         from zebrazoom.code.dataPostProcessing.findSleepVsMoving import calculateSleepVsMovingPeriods
-        pathToZZoutput = os.path.join(dir_path,'ZZoutput')
+        pathToZZoutput = paths.getDefaultZZoutputFolder()
         videoName      = sys.argv[3]
         speedThresholdForMoving = float(sys.argv[4])
         notMovingNumberOfFramesThresholdForSleep = int(sys.argv[5])
@@ -121,7 +126,7 @@ if __name__ == '__main__':
 
       if sys.argv[2] == "firstSleepingTimeAfterSpecifiedTime":
         from zebrazoom.code.dataPostProcessing.findSleepVsMoving import firstSleepingTimeAfterSpecifiedTime
-        pathToZZoutput = os.path.join(dir_path,'ZZoutput')
+        pathToZZoutput = paths.getDefaultZZoutputFolder()
         videoName      = sys.argv[3]
         specifiedTime  = sys.argv[4]
         wellNumber     = sys.argv[5]
@@ -129,7 +134,7 @@ if __name__ == '__main__':
 
       if sys.argv[2] == "numberOfSleepingAndMovingTimesInTimeRange":
         from zebrazoom.code.dataPostProcessing.findSleepVsMoving import numberOfSleepingAndMovingTimesInTimeRange
-        pathToZZoutput     = os.path.join(dir_path,'ZZoutput')
+        pathToZZoutput     = paths.getDefaultZZoutputFolder()
         videoName          = sys.argv[3]
         specifiedStartTime = sys.argv[4]
         specifiedEndTime   = sys.argv[5]
@@ -138,7 +143,7 @@ if __name__ == '__main__':
 
       if sys.argv[2] == "numberOfSleepBoutsInTimeRange":
         from zebrazoom.code.dataPostProcessing.findSleepVsMoving import numberOfSleepBoutsInTimeRange
-        pathToZZoutput                  = os.path.join(dir_path,'ZZoutput')
+        pathToZZoutput                  = paths.getDefaultZZoutputFolder()
         videoName                       = sys.argv[3]
         minSleepLenghtDurationThreshold = int(sys.argv[4])
         wellNumber                      = sys.argv[5] if len(sys.argv) >= 6 else '-1'
@@ -148,7 +153,7 @@ if __name__ == '__main__':
 
       if sys.argv[2] == "calculateNumberOfSfsVsTurnsBasedOnMaxAmplitudeThreshod":
         from zebrazoom.dataAnalysis.postProcessingFromCommandLine.postProcessingFromCommandLine import calculateNumberOfSfsVsTurnsBasedOnMaxAmplitudeThreshold
-        calculateNumberOfSfsVsTurnsBasedOnMaxAmplitudeThreshold(dir_path, sys.argv[3], int(sys.argv[4]))
+        calculateNumberOfSfsVsTurnsBasedOnMaxAmplitudeThreshold(paths.getRootDataFolder(), sys.argv[3], int(sys.argv[4]))
 
       if sys.argv[2] == "kinematicParametersAnalysis":
         from zebrazoom.kinematicParametersAnalysis import kinematicParametersAnalysis
@@ -166,12 +171,15 @@ if __name__ == '__main__':
         from zebrazoom.clusteringAnalysisPerFrame import clusteringAnalysisPerFrame
         clusteringAnalysisPerFrame(sys)
 
+      if sys.argv[2] == "kinematicParametersAnalysisCenterOfMassOnlyNoBoutsDetection":
+        from zebrazoom.kinematicParametersAnalysisCenterOfMassOnlyNoBoutsDetection import kinematicParametersAnalysisCenterOfMassOnlyNoBoutsDetection
+        kinematicParametersAnalysisCenterOfMassOnlyNoBoutsDetection(sys)
 
     elif sys.argv[1] == "visualizeMovingAndSleepingTime":
 
       from zebrazoom.code.readValidationVideo import readValidationVideo
       import pandas as pd
-      df = pd.read_excel(os.path.join(os.path.join(os.path.join(dir_path, 'ZZoutput'), sys.argv[3]), "sleepVsMoving_" + sys.argv[3] + ".xlsx"))
+      df = pd.read_excel(os.path.join(paths.getDefaultZZoutputFolder(), sys.argv[3], "sleepVsMoving_" + sys.argv[3] + ".xlsx"))
       nbWells = int(len(df.columns)/3)
 
       if sys.argv[2] == "movingTime":
@@ -184,6 +192,11 @@ if __name__ == '__main__':
         framesToShow = df[["sleep_" + str(i) for i in range(0, nbWells)]].to_numpy()
         readValidationVideo("", sys.argv[3], "", -1, -1, 0, 1, framesToShow)
 
+    elif sys.argv[1] == "createDistanceBetweenFramesExcelFile":
+
+      from zebrazoom.dataAnalysis.createCustomDataStructure.createDistanceBetweenFramesExcelFile import createDistanceBetweenFramesExcelFile
+      createDistanceBetweenFramesExcelFile(paths.getDefaultZZoutputFolder(), sys.argv) # fps, pixelSize
+      
 
     elif sys.argv[1] == "otherScripts":
 
@@ -202,9 +215,13 @@ if __name__ == '__main__':
         from zebrazoom.otherScripts.launchReapplyClustering import launchReapplyClustering
         launchReapplyClustering()
 
+    elif sys.argv[1] == "--exit":
+      from PyQt5.QtCore import QTimer
+      QTimer.singleShot(0, app.window.close)
+      sys.exit(app.exec())
     else:
 
-      print("The data produced by ZebraZoom can be found in the folder: " + os.path.join(dir_path,'ZZoutput'))
+      print("The data produced by ZebraZoom can be found in the folder: " + paths.getDefaultZZoutputFolder())
       pathToVideo = sys.argv[1]
       videoName   = sys.argv[2]
       videoExt    = sys.argv[3]
