@@ -16,7 +16,7 @@ from matplotlib.figure import Figure
 from PyQt5.QtCore import pyqtSignal, Qt, QDir, QEvent, QLine, QObject, QPoint, QPointF, QRect, QSize, QSortFilterProxyModel, QTimer, QUrl
 from PyQt5.QtGui import QColor, QCursor, QFont, QFontMetrics, QPainter, QPainterPath, QPolygonF
 from PyQt5.QtNetwork import QNetworkAccessManager, QNetworkReply, QNetworkRequest
-from PyQt5.QtWidgets import QApplication, QLabel, QWidget, QFileSystemModel, QFrame, QGridLayout, QHeaderView, QPushButton, QSizePolicy, QSplitter, QHBoxLayout, QVBoxLayout, QCheckBox, QScrollArea, QSpinBox, QComboBox, QTreeView, QToolTip
+from PyQt5.QtWidgets import QApplication, QLabel, QWidget, QFileSystemModel, QFrame, QGridLayout, QHeaderView, QPushButton, QSizePolicy, QHBoxLayout, QVBoxLayout, QCheckBox, QScrollArea, QSpinBox, QComboBox, QTreeView, QToolTip
 PYQT6 = False
 
 import zebrazoom.code.paths as paths
@@ -187,15 +187,15 @@ class _AnalysisDetails(QFrame):
 
     app = QApplication.instance()
     layout = QVBoxLayout()
-    analyzeOutputBtn = util.apply_style(QPushButton("Analyze ZebraZoom's output", self), background_color=util.LIGHT_YELLOW)
-    analyzeOutputBtn.clicked.connect(lambda: app.show_frame("CreateExperimentOrganizationExcel"))
-    layout.addWidget(analyzeOutputBtn, alignment=Qt.AlignmentFlag.AlignCenter)
+    self._analyzeOutputBtn = util.apply_style(QPushButton("Analyze ZebraZoom's output"), background_color=util.LIGHT_YELLOW)
+    self._analyzeOutputBtn.clicked.connect(lambda: app.show_frame("CreateExperimentOrganizationExcel"))
+    layout.addWidget(self._analyzeOutputBtn, alignment=Qt.AlignmentFlag.AlignCenter)
     analyzeOutputLabel = QLabel('Kinematic parameters analysis and unsupervised clustering are available right from the GUI!')
     analyzeOutputLabel.setWordWrap(True)
     layout.addWidget(analyzeOutputLabel, alignment=Qt.AlignmentFlag.AlignCenter)
-    outputFolderBtn = util.apply_style(QPushButton("Open ZebraZoom's\noutput folder", self), background_color=util.LIGHT_YELLOW)
-    outputFolderBtn.clicked.connect(lambda: app.openZZOutputFolder(app.homeDirectory))
-    layout.addWidget(outputFolderBtn, alignment=Qt.AlignmentFlag.AlignCenter)
+    self._outputFolderBtn = util.apply_style(QPushButton("Open ZebraZoom's\noutput folder"), background_color=util.LIGHT_YELLOW)
+    self._outputFolderBtn.clicked.connect(lambda: app.openZZOutputFolder(app.homeDirectory))
+    layout.addWidget(self._outputFolderBtn, alignment=Qt.AlignmentFlag.AlignCenter)
     outputFolderLabel = QLabel('Go one step further: access the raw data and do your own analysis!')
     outputFolderLabel.setWordWrap(True)
     layout.addWidget(outputFolderLabel, alignment=Qt.AlignmentFlag.AlignCenter)
@@ -212,9 +212,9 @@ class StartPage(QWidget):
 
         layout = QGridLayout()
         layout.setVerticalSpacing(20)
-        titleLabel = util.apply_style(QLabel("Welcome to ZebraZoom!", self), font=controller.title_font, color='purple')
-        titleLabel.setSizePolicy(QSizePolicy(QSizePolicy.Policy.Fixed, QSizePolicy.Policy.Fixed))
-        layout.addWidget(titleLabel, 0, 0, 1, 4, Qt.AlignmentFlag.AlignHCenter)
+        self._titleLabel = util.apply_style(QLabel("Welcome to ZebraZoom!"), font=controller.title_font, color='purple')
+        self._titleLabel.setSizePolicy(QSizePolicy(QSizePolicy.Policy.Fixed, QSizePolicy.Policy.Fixed))
+        layout.addWidget(self._titleLabel, 0, 0, 1, 4, Qt.AlignmentFlag.AlignHCenter)
         self._flowchart = _FlowchartWidget()
         layout.addWidget(self._flowchart, 1, 0, 1, 4)
         for idx, widget in enumerate(self._detailsWidgets):
@@ -223,17 +223,17 @@ class StartPage(QWidget):
           layout.setColumnStretch(idx, 1)
 
         bottomLayout = QHBoxLayout()
-        toubleshootBtn = QPushButton("Troubleshoot", self)
-        toubleshootBtn.clicked.connect(lambda: controller.show_frame("ChooseVideoToTroubleshootSplitVideo"))
-        bottomLayout.addWidget(toubleshootBtn)
-        documentationBtn = QPushButton("Documentation", self)
-        documentationBtn.clicked.connect(lambda: webbrowser.open_new("https://zebrazoom.org/documentation/docs/intro/"))
-        bottomLayout.addWidget(documentationBtn)
-        self._updateStatusLabel = QLabel("Regularly update your version of ZebraZoom with: 'pip install zebrazoom --upgrade'!", self)
+        self._troubleshootBtn = QPushButton("Troubleshoot")
+        self._troubleshootBtn.clicked.connect(lambda: controller.show_frame("ChooseVideoToTroubleshootSplitVideo"))
+        bottomLayout.addWidget(self._troubleshootBtn)
+        self._documentationBtn = QPushButton("Documentation")
+        self._documentationBtn.clicked.connect(lambda: webbrowser.open_new("https://zebrazoom.org/documentation/docs/intro/"))
+        bottomLayout.addWidget(self._documentationBtn)
+        self._updateStatusLabel = QLabel("Regularly update your version of ZebraZoom with: 'pip install zebrazoom --upgrade'!")
         bottomLayout.addWidget(self._updateStatusLabel)
         if getattr(sys, 'frozen', False):  # running an installed executable
             self._networkManager = QNetworkAccessManager()
-            self._updateBtn = QPushButton('', self)
+            self._updateBtn = QPushButton('')
             bottomLayout.addWidget(self._updateBtn)
             QTimer.singleShot(0, self._checkForUpdates)
         layout.addLayout(bottomLayout, 2, 0, 1, 4, alignment=Qt.AlignmentFlag.AlignHCenter | Qt.AlignmentFlag.AlignBottom)
@@ -584,7 +584,7 @@ class _TooltipHelper(QObject):
     return False
 
 
-class ViewParameters(QSplitter):
+class ViewParameters(util.CollapsibleSplitter):
     def __init__(self, controller):
         super().__init__(controller.window)
         self.controller = controller
