@@ -15,12 +15,10 @@ from zebrazoom.code.findWells import findWells
 from zebrazoom.code.trackingFolder.tracking import tracking
 from zebrazoom.code.GUI.adjustParameterInsideAlgoFunctions import prepareConfigFileForParamsAdjustements
 from zebrazoom.code.resizeImageTooLarge import resizeImageTooLarge
+import zebrazoom.code.paths as paths
 import zebrazoom.code.util as util
 
-try:
-  from PyQt6.QtWidgets import QApplication
-except ImportError:
-  from PyQt5.QtWidgets import QApplication
+from PyQt5.QtWidgets import QApplication
 
 
 def getGroundTruthFromUser(self, controller, nbOfImagesToManuallyClassify, saveIntermediary, zebrafishToTrack):
@@ -90,7 +88,7 @@ def getGroundTruthFromUser(self, controller, nbOfImagesToManuallyClassify, saveI
     oldk = k
     if data[k//backCalculationStep] is None:
       headCoordinates = list(util.getPoint(frame, "Click on the center of the head of one animal" if zebrafishToTrack else "Click on the center of mass of an animal",
-                                           backBtnCb=callback))
+                                           backBtnCb=callback, zoomable=True))
     else:
       headCoordinates = data[k//backCalculationStep]["headCoordinates"]
     if oldk != k:
@@ -103,7 +101,7 @@ def getGroundTruthFromUser(self, controller, nbOfImagesToManuallyClassify, saveI
         return None
     frame2 = cv2.circle(frame, tuple(headCoordinates), 2, (0, 0, 255), -1)
     tailTipCoordinates = list(util.getPoint(frame2, "Click on the tip of the tail of the same animal" if zebrafishToTrack else "Click on a point on the border of the same animal",
-                              backBtnCb=callback))
+                              backBtnCb=callback, zoomable=True))
     if oldk != k:
       k = oldk
       if data[k//backCalculationStep] is not None:
@@ -370,7 +368,7 @@ def boutDetectionParameters(data, configFile, pathToVideo, videoName, videoExt,
     try:
       mainZZ(pathToVideo, videoName, videoExt, configFile, [])
     except ValueError:
-      newhyperparameters = pickle.load(open('newhyperparameters', 'rb'))
+      newhyperparameters = pickle.load(open(os.path.join(paths.getRootDataFolder(), 'newhyperparameters'), 'rb'))
       for index in newhyperparameters:
         configFile[index] = newhyperparameters[index]
     except NameError:
