@@ -1,15 +1,12 @@
+import math
+import sys
+
 import cv2
 
-try:
-  from PyQt6.QtCore import pyqtSignal, Qt, QAbstractAnimation, QEventLoop, QParallelAnimationGroup, QPoint, QPointF, QPropertyAnimation, QRectF, QSize, QSizeF, QTimer
-  from PyQt6.QtGui import QBrush, QColor, QFont, QImage, QPainter, QPen, QPixmap, QPolygonF, QTransform
-  from PyQt6.QtWidgets import QApplication, QFrame, QGraphicsPixmapItem, QGraphicsScene, QGraphicsView, QGridLayout, QLabel, QLayout, QHBoxLayout, QPushButton, QScrollArea, QSizePolicy, QSlider, QSpinBox, QToolButton, QToolTip, QVBoxLayout, QWidget
-  PYQT6 = True
-except ImportError:
-  from PyQt5.QtCore import pyqtSignal, Qt, QAbstractAnimation, QEventLoop, QParallelAnimationGroup, QPoint, QPointF, QPropertyAnimation, QRectF, QSize, QSizeF, QTimer
-  from PyQt5.QtGui import QBrush, QColor, QFont, QImage, QPainter, QPen, QPixmap, QPolygonF, QTransform
-  from PyQt5.QtWidgets import QApplication, QFrame, QGraphicsPixmapItem, QGraphicsScene, QGraphicsView, QGridLayout, QLabel, QLayout, QHBoxLayout, QPushButton, QScrollArea, QSizePolicy, QSlider, QSpinBox, QToolButton, QToolTip, QVBoxLayout, QWidget
-  PYQT6 = False
+from PyQt5.QtCore import pyqtSignal, Qt, QAbstractAnimation, QEventLoop, QLine, QParallelAnimationGroup, QPoint, QPointF, QPropertyAnimation, QRectF, QSize, QSizeF, QStandardPaths, QTimer
+from PyQt5.QtGui import QBrush, QColor, QFont, QImage, QPainter, QPen, QPixmap, QPolygonF, QTransform
+from PyQt5.QtWidgets import QApplication, QFrame, QGraphicsPixmapItem, QGraphicsScene, QGraphicsView, QGridLayout, QLabel, QLayout, QHBoxLayout, QPushButton, QScrollArea, QSizePolicy, QSlider, QSpinBox, QSplitter, QSplitterHandle, QToolButton, QToolTip, QVBoxLayout, QWidget
+PYQT6 = False
 
 import zebrazoom.videoFormatConversion.zzVideoReading as zzVideoReading
 
@@ -137,36 +134,49 @@ def showBlockingPage(layout, title=None, buttons=(), dialog=False, labelInfo=Non
   stackedLayout.removeWidget(temporaryPage)
 
 
-def showDialog(layout, title=None, buttons=(), dialog=False, labelInfo=None, timeout=None):
+def showDialog(layout, title=None, buttons=(), labelInfo=None, timeout=None, exitSignals=()):
   dialog = QWidget()
+  for signal in exitSignals:
+    signal.connect(lambda *args: dialog.close())
   loop = QEventLoop()
   mainLayout = QVBoxLayout()
   mainLayout.addLayout(layout)
   mainLayout.addLayout(_getButtonsLayout(buttons, loop, dialog=dialog))
   app = QApplication.instance()
-  if app is not None:
+  if hasattr(app, 'registerWindow'):
     app.registerWindow(dialog)
   dialog.setWindowTitle(title)
   dialog.move(0, 0)
   dialog.setWindowModality(Qt.WindowModality.ApplicationModal)
   dialog.setLayout(mainLayout)
   if labelInfo is not None:
-    img, label = labelInfo
+    if len(labelInfo) == 2:
+      img, label = labelInfo
+      zoomable = False
+    else:
+      assert len(labelInfo) == 3
+      img, label, zoomable = labelInfo
     height, width = img.shape[:2]
     label.setMinimumSize(width, height)
     layoutSize = mainLayout.totalSizeHint()
     label.setMinimumSize(1, 1)
-    extraWidth = layoutSize.width() - width
-    extraHeight = layoutSize.height() - height
   else:
     layoutSize = mainLayout.totalSizeHint()
   screenSize = QApplication.primaryScreen().availableSize()
+  if hasattr(app, 'window'):
+    screenSize -= app.window.frameSize() - app.window.size()
   if layoutSize.width() > screenSize.width() or layoutSize.height() > screenSize.height():
     layoutSize.scale(screenSize, Qt.AspectRatioMode.KeepAspectRatio)
   dialog.setFixedSize(layoutSize)
   dialog.show()
   if labelInfo is not None:
-    setPixmapFromCv(*labelInfo, QSize(layoutSize.width() - extraWidth, layoutSize.height() - extraHeight))
+    if len(labelInfo) == 2:
+      img, label = labelInfo
+      zoomable = False
+    else:
+      assert len(labelInfo) == 3
+      img, label, zoomable = labelInfo
+    setPixmapFromCv(img, label, preferredSize=QSize(width, height).scaled(label.size(), Qt.AspectRatioMode.KeepAspectRatio), zoomable=zoomable)
   dialog.closeEvent = _dialogClosed(loop, dialog.closeEvent)
   if timeout is not None:
     QTimer.singleShot(timeout, lambda: dialog.close())
@@ -187,19 +197,20 @@ def _cvToPixmap(img):
 
 class ZoomableImage(QGraphicsView):
   pointSelected = pyqtSignal(QPoint)
+  proceed = pyqtSignal()
 
   def __init__(self, parent=None):
     super(ZoomableImage, self).__init__(parent)
     self._zoom = 0
     self._scene = QGraphicsScene(self)
-    self._pixmap = QGraphicsPixmapItem() # TODO: rename
+    self._pixmap = QGraphicsPixmapItem()
     self._scene.addItem(self._pixmap)
     self.setScene(self._scene)
-    self.setTransformationAnchor(QGraphicsView.AnchorUnderMouse)
-    self.setResizeAnchor(QGraphicsView.AnchorUnderMouse)
-    self.setVerticalScrollBarPolicy(Qt.ScrollBarAlwaysOff)
-    self.setHorizontalScrollBarPolicy(Qt.ScrollBarAlwaysOff)
-    self.setFrameShape(QFrame.NoFrame)
+    self.setTransformationAnchor(QGraphicsView.ViewportAnchor.AnchorUnderMouse)
+    self.setResizeAnchor(QGraphicsView.ViewportAnchor.AnchorUnderMouse)
+    self.setVerticalScrollBarPolicy(Qt.ScrollBarPolicy.ScrollBarAlwaysOff)
+    self.setHorizontalScrollBarPolicy(Qt.ScrollBarPolicy.ScrollBarAlwaysOff)
+    self.setFrameShape(QFrame.Shape.NoFrame)
     self._point = None
     self._dragging = False
     self._tooltipShown = False
@@ -216,28 +227,45 @@ class ZoomableImage(QGraphicsView):
     self.scale(factor, factor)
     self._zoom = 0
 
-  def setPhoto(self, pixmap):
+  def setPixmap(self, pixmap):
     self._zoom = 0
-    self.setDragMode(QGraphicsView.ScrollHandDrag)
+    self.setDragMode(QGraphicsView.DragMode.ScrollHandDrag)
     self._pixmap.setPixmap(pixmap)
     self.fitInView()
 
-  def wheelEvent(self, evt):
-    if evt.angleDelta().y() > 0:
-      factor = 1.25
-      self._zoom += 1
-    else:
-      factor = 0.8
-      self._zoom -= 1
+  def _update(self, scaleFactor):
     if self._zoom > 0:
-      self.scale(factor, factor)
+      self.scale(scaleFactor, scaleFactor)
     elif self._zoom == 0:
       self.fitInView()
     else:
       self._zoom = 0
 
+  def wheelEvent(self, evt):
+    if evt.angleDelta().y() > 0:
+      self._zoom += 1
+      self._update(1.25)
+    else:
+      self._zoom -= 1
+      self._update(0.8)
+
+  def keyPressEvent(self, evt):
+    if self._point is not None and (evt.key() == Qt.Key.Key_Enter or evt.key() == Qt.Key.Key_Return):
+      self.proceed.emit()
+      return
+    elif evt.modifiers() & Qt.KeyboardModifier.ControlModifier:
+      if evt.key() == Qt.Key.Key_Plus:
+        self._zoom += 1
+        self._update(1.25)
+        return
+      if evt.key() == Qt.Key.Key_Minus:
+        self._zoom -= 1
+        self._update(0.8)
+        return
+    super().keyPressEvent(evt)
+
   def mouseMoveEvent(self, evt):
-    if evt.buttons() == Qt.LeftButton and not self._dragging:
+    if evt.buttons() == Qt.MouseButton.LeftButton and not self._dragging:
       self._dragging = True
       QApplication.setOverrideCursor(Qt.CursorShape.ClosedHandCursor)
     super().mouseMoveEvent(evt)
@@ -264,7 +292,7 @@ class ZoomableImage(QGraphicsView):
     if self._point is not None:
       qp.setBrush(QColor(255, 0, 0))
       qp.setPen(Qt.PenStyle.NoPen)
-      qp.drawEllipse(self.mapFromScene(self._point), 2, 2)
+      qp.drawEllipse(self.mapFromScene(QPointF(self._point)), 2, 2)
     qp.end()
 
   def enterEvent(self, evt):
@@ -298,14 +326,17 @@ def setPixmapFromCv(img, label, preferredSize=None, zoomable=False):
     label.hide()
     image = ZoomableImage()
     image.sizeHint = lambda: size
-    image.viewport().setMinimumSize(size)
-    image.setPhoto(originalPixmap)
+    image.setMaximumSize(size)
+    image.viewport().setFixedSize(size)
+    image.setPixmap(originalPixmap)
     label.parentWidget().layout().replaceWidget(label, image)
+    image.setFocus()
     if hasattr(image, "pointSelected"):
       def pointSelected(point):
         label.pointSelected.emit(point)
         label.getCoordinates = lambda: (point.x(), point.y())
       image.pointSelected.connect(pointSelected)
+      image.proceed.connect(label.proceed.emit)
 
 
 class SliderWithSpinbox(QWidget):
@@ -374,7 +405,6 @@ def _chooseFrameLayout(cap, spinboxValues, title, titleStyle=None):
   if titleStyle is None:
     titleStyle = {'font': TITLE_FONT}
   layout = QVBoxLayout()
-  window = QApplication.instance().window
   titleLabel = apply_style(QLabel(title), **titleStyle)
   titleLabel.setMinimumSize(1, 1)
   titleLabel.resizeEvent = lambda evt: titleLabel.setMinimumWidth(evt.size().width()) or titleLabel.setWordWrap(evt.size().width() <= titleLabel.sizeHint().width())
@@ -440,11 +470,13 @@ def _chooseFrameLayout(cap, spinboxValues, title, titleStyle=None):
 
   return layout, video, frameSlider
 
-def chooseBeginningPage(app, videoPath, title, chooseFrameBtnText, chooseFrameBtnCb, extraButtonInfo=None, titleStyle=None):
+def chooseBeginningPage(app, videoPath, title, chooseFrameBtnText, chooseFrameBtnCb, extraButtonInfo=None, titleStyle=None, additionalLayout=None):
   cap = zzVideoReading.VideoCapture(videoPath)
   cap.set(1, 1)
   ret, frame = cap.read()
   layout, label, valueWidget = _chooseFrameLayout(cap, (1, 0, cap.get(7) - 2), title, titleStyle=titleStyle)
+  if additionalLayout is not None:
+    layout.addLayout(additionalLayout)
 
   buttonsLayout = QHBoxLayout()
   buttonsLayout.addStretch()
@@ -460,8 +492,13 @@ def chooseBeginningPage(app, videoPath, title, chooseFrameBtnText, chooseFrameBt
   buttonsLayout.addWidget(chooseFrameBtn)
   extraBtn = None
   if extraButtonInfo is not None:
-    text, cb = extraButtonInfo
-    extraBtn = QPushButton(text)
+    if len(extraButtonInfo) == 2:
+      text, cb = extraButtonInfo
+      styleKwargs = {}
+    else:
+      assert len(extraButtonInfo) == 3
+      text, cb, styleKwargs = extraButtonInfo
+    extraBtn = apply_style(QPushButton(text), **styleKwargs)
     extraBtn.clicked.connect(cb)
     buttonsLayout.addWidget(extraBtn)
   buttonsLayout.addStretch()
@@ -495,9 +532,10 @@ def chooseEndPage(app, videoPath, title, chooseFrameBtnText, chooseFrameBtnCb):
 
   buttonsLayout = QHBoxLayout()
   buttonsLayout.addStretch()
-  backBtn = QPushButton("Back")
-  backBtn.setObjectName("back")
-  buttonsLayout.addWidget(backBtn)
+  if app.configFileHistory:
+    backBtn = QPushButton("Back")
+    backBtn.setObjectName("back")
+    buttonsLayout.addWidget(backBtn)
   chooseFrameBtn = QPushButton(chooseFrameBtnText)
   def chooseFrameBtnClicked():
     app.configFile["lastFrame"] = valueWidget.value()
@@ -516,12 +554,13 @@ def chooseEndPage(app, videoPath, title, chooseFrameBtnText, chooseFrameBtnCb):
     label.setMinimumSize(1, 1)
     label.show()
     setPixmapFromCv(frame, label)
-  for btn in (backBtn, chooseFrameBtn):
+  for btn in (backBtn, chooseFrameBtn) if app.configFileHistory else (chooseFrameBtn,):
     btn.clicked.connect(lambda: stackedLayout.removeWidget(page))
 
 
 class _InteractiveLabelPoint(QLabel):
   pointSelected = pyqtSignal(QPoint)
+  proceed = pyqtSignal()
 
   def __init__(self, width, height, selectingRegion):
     super().__init__()
@@ -531,9 +570,16 @@ class _InteractiveLabelPoint(QLabel):
     self._selectingRegion = selectingRegion
     self._currentPosition = None
     self._tooltipShown = False
+    self.setFocusPolicy(Qt.FocusPolicy.StrongFocus)
     if self._selectingRegion:
       self.setMouseTracking(True)
 
+  def keyPressEvent(self, evt):
+    if self._point is not None and (evt.key() == Qt.Key.Key_Enter or evt.key() == Qt.Key.Key_Return):
+      self.proceed.emit()
+      return
+    super().keyPressEvent(evt)
+
   def mouseMoveEvent(self, evt):
     if self._selectingRegion:
       self._currentPosition = evt.pos()
@@ -586,12 +632,15 @@ class _InteractiveLabelPoint(QLabel):
     return point.x(), point.y()
 
 
-def getPoint(frame, title, extraButtons=(), selectingRegion=False, backBtnCb=None, zoomable=False, useNext=True):
+def getPoint(frame, title, extraButtons=(), selectingRegion=False, backBtnCb=None, zoomable=False, useNext=True, dialog=False):
   height, width = frame.shape[:2]
 
   layout = QVBoxLayout()
+  additionalText = "Enter/Return keys can be used instead of clicking Next."
   if zoomable:
-    layout.addWidget(QLabel("You can zoom in/out using the mouse wheel and drag the image."), alignment=Qt.AlignmentFlag.AlignCenter)
+    controlModifier = 'Ctrl' if sys.platform != 'darwin' else 'Cmd'  # Qt documentation explicilty states this
+    additionalText += "\nYou can zoom in/out using the mouse wheel or %s and +/- and drag the image." % controlModifier
+  layout.addWidget(QLabel(additionalText), alignment=Qt.AlignmentFlag.AlignCenter)
 
   video = _InteractiveLabelPoint(width, height, selectingRegion)
   extraButtons = tuple((text, lambda: cb(video), exitLoop) for text, cb, exitLoop in extraButtons)
@@ -600,7 +649,10 @@ def getPoint(frame, title, extraButtons=(), selectingRegion=False, backBtnCb=Non
   layout.addWidget(video, alignment=Qt.AlignmentFlag.AlignCenter, stretch=1)
   if not useNext:
     video.pointSelected.connect(lambda: QApplication.restoreOverrideCursor())
-  showBlockingPage(layout, title=title, buttons=buttons + extraButtons, labelInfo=(frame, video, zoomable), exitSignals=() if useNext else (video.pointSelected,))
+  if not dialog:
+    showBlockingPage(layout, title=title, buttons=buttons + extraButtons, labelInfo=(frame, video, zoomable), exitSignals=(video.proceed,) if useNext else (video.pointSelected,))
+  else:
+    showDialog(layout, title=title, buttons=buttons + extraButtons, labelInfo=(frame, video, zoomable), exitSignals=(video.proceed,) if useNext else (video.pointSelected,))
   return video.getCoordinates()
 
 
@@ -683,7 +735,7 @@ class _InteractiveLabelRect(QLabel):
     return ([point.x(), point.y()] for point in points)
 
 
-def getRectangle(frame, title, backBtnCb=None):
+def getRectangle(frame, title, backBtnCb=None, dialog=False):
   height, width, _ = frame.shape
 
   layout = QVBoxLayout()
@@ -694,11 +746,153 @@ def getRectangle(frame, title, backBtnCb=None):
     buttons = (("Back", backBtnCb, True), ("Next", None, True, video.regionSelected))
   else:
     buttons = (("Next", None, True, video.regionSelected),)
-  showBlockingPage(layout, title=title, buttons=buttons, labelInfo=(frame, video))
+  if not dialog:
+    showBlockingPage(layout, title=title, buttons=buttons, labelInfo=(frame, video))
+  else:
+    showDialog(layout, title=title, buttons=buttons, labelInfo=(frame, video))
 
   return video.getCoordinates()
 
 
+class _CVLabelLine(QLabel):
+  pointSelected = pyqtSignal(QPoint)
+  proceed = pyqtSignal()
+
+  def __init__(self, width, height, frame, thickness, startPoint):
+    super().__init__()
+    self._width = width
+    self._height = height
+    self._point = None
+    self._currentPosition = None
+    self.setFocusPolicy(Qt.FocusPolicy.StrongFocus)
+    self.setMouseTracking(True)
+    self._thickness = thickness
+    self._startPoint = startPoint
+    self._frame = frame
+
+  def keyPressEvent(self, evt):
+    if self._point is not None and (evt.key() == Qt.Key.Key_Enter or evt.key() == Qt.Key.Key_Return):
+      self.proceed.emit()
+      return
+    super().keyPressEvent(evt)
+
+  def mouseMoveEvent(self, evt):
+    self._currentPosition = evt.pos()
+    point = self._currentPosition
+    if self._size.height() != self._height or self._size.width() != self._width:
+      point = transformCoordinates(QRectF(QPointF(0, 0), QSizeF(self._size)), QRectF(QPointF(0, 0), QSizeF(self._width, self._height)), point)
+    setPixmapFromCv(cv2.line(self._frame.copy(), (self._startPoint), (point.x(), point.y()), (255, 255, 255), self._thickness), self)
+
+  def mousePressEvent(self, evt):
+    self._point = evt.pos()
+    self.pointSelected.emit(self._point)
+
+  def enterEvent(self, evt):
+    QApplication.setOverrideCursor(Qt.CursorShape.CrossCursor)
+
+  def leaveEvent(self, evt):
+    QApplication.restoreOverrideCursor()
+    self._currentPosition = None
+
+  def resizeEvent(self, evt):
+    super().resizeEvent(evt)
+    self._size = self.size()
+
+  def getCoordinates(self):
+    if self._point is None:
+      return 0, 0
+    point = self._point
+    if self._size.height() != self._height or self._size.width() != self._width:
+      point = transformCoordinates(QRectF(QPointF(0, 0), QSizeF(self._size)), QRectF(QPointF(0, 0), QSizeF(self._width, self._height)), self._point)
+    return point.x(), point.y()
+
+
+def getLine(frame, title, thickness, startPoint):
+  height, width = frame.shape[:2]
+
+  layout = QVBoxLayout()
+
+  video = _CVLabelLine(width, height, frame, thickness, startPoint)
+  layout.addWidget(video, alignment=Qt.AlignmentFlag.AlignCenter)
+  buttons = (("Next", None, True),)
+  showDialog(layout, title=title, buttons=buttons, labelInfo=(frame, video), exitSignals=(video.pointSelected,))
+
+  return video.getCoordinates()
+
+
+class _CVDrawLabel(QLabel):
+  proceed = pyqtSignal()
+
+  def __init__(self, width, height, frame):
+    super().__init__()
+    self._width = width
+    self._height = height
+    self.setFocusPolicy(Qt.FocusPolicy.StrongFocus)
+    self._frame = frame
+
+  def keyPressEvent(self, evt):
+    if self._point is not None and (evt.key() == Qt.Key.Key_Enter or evt.key() == Qt.Key.Key_Return):
+      self.proceed.emit()
+      return
+    super().keyPressEvent(evt)
+
+  def mouseMoveEvent(self, evt):
+    point = evt.pos()
+    if self._size.height() != self._height or self._size.width() != self._width:
+      point = transformCoordinates(QRectF(QPointF(0, 0), QSizeF(self._size)), QRectF(QPointF(0, 0), QSizeF(self._width, self._height)), point)
+    self._frame = cv2.circle(self._frame, (point.x(), point.y()), 3, (255, 255, 255), -1)
+    setPixmapFromCv(self._frame, self)
+
+  def mousePressEvent(self, evt):
+    point = evt.pos()
+    if self._size.height() != self._height or self._size.width() != self._width:
+      point = transformCoordinates(QRectF(QPointF(0, 0), QSizeF(self._size)), QRectF(QPointF(0, 0), QSizeF(self._width, self._height)), point)
+    self._frame = cv2.circle(self._frame, (point.x(), point.y()), 3, (255, 255, 255), -1)
+    setPixmapFromCv(self._frame, self)
+
+  def enterEvent(self, evt):
+    QApplication.setOverrideCursor(Qt.CursorShape.CrossCursor)
+
+  def leaveEvent(self, evt):
+    QApplication.restoreOverrideCursor()
+
+  def resizeEvent(self, evt):
+    super().resizeEvent(evt)
+    self._size = self.size()
+
+  def getFrame(self):
+    return self._frame
+
+
+def drawPoints(frame, title):
+  height, width = frame.shape[:2]
+
+  layout = QVBoxLayout()
+
+  video = _CVDrawLabel(width, height, frame)
+  layout.addWidget(video, alignment=Qt.AlignmentFlag.AlignCenter)
+  buttons = (("Done", None, True),)
+  showDialog(layout, title=title, buttons=buttons, labelInfo=(frame, video))
+  return video.getFrame()
+
+
+class _FrameLabel(QLabel):
+  proceed = pyqtSignal()
+
+  def keyPressEvent(self, evt):
+    super().keyPressEvent(evt)
+    self.proceed.emit()
+
+
+def showFrame(frame, title='', buttons=(), timeout=None):
+  label = _FrameLabel()
+  label.setMinimumSize(1, 1)
+  label.setFocusPolicy(Qt.FocusPolicy.StrongFocus)
+  layout = QVBoxLayout()
+  layout.addWidget(label, alignment=Qt.AlignmentFlag.AlignCenter)
+  showDialog(layout, title=title, buttons=buttons, labelInfo=(frame, label), timeout=timeout, exitSignals=(label.proceed,))
+
+
 def addToHistory(fn):
   def inner(*args, **kwargs):
     app = QApplication.instance()
@@ -715,19 +909,20 @@ def addToHistory(fn):
 
 
 class Expander(QWidget):
-  def __init__(self, parent, title, layout, animationDuration=200):
-    super(Expander, self).__init__(parent)
+  def __init__(self, parent, title, layout, animationDuration=200, showFrame=False, addScrollbars=False):
+    super(Expander, self).__init__()
 
-    toggleButton = QToolButton()
+    self._toggleButton = toggleButton = QToolButton()
     toggleButton.setStyleSheet("QToolButton { border: none; }")
-    toggleButton.setToolButtonStyle(Qt.ToolButtonTextBesideIcon)
-    toggleButton.setArrowType(Qt.RightArrow)
+    toggleButton.setToolButtonStyle(Qt.ToolButtonStyle.ToolButtonTextBesideIcon)
+    toggleButton.setArrowType(Qt.ArrowType.RightArrow)
     toggleButton.setText(str(title))
     toggleButton.setCheckable(True)
     toggleButton.setChecked(False)
 
-    contentArea = QScrollArea()
-    contentArea.setFrameShape(QFrame.Shape.NoFrame)
+    self._contentArea = contentArea = QScrollArea()
+    if not showFrame:
+      contentArea.setFrameShape(QFrame.Shape.NoFrame)
     contentArea.setSizePolicy(QSizePolicy.Policy.Expanding, QSizePolicy.Policy.Preferred)
     contentArea.setMaximumHeight(0)
     contentArea.setMinimumHeight(0)
@@ -735,31 +930,197 @@ class Expander(QWidget):
     mainLayout = QGridLayout()
     mainLayout.setVerticalSpacing(0)
     mainLayout.setContentsMargins(0, 0, 0, 0)
-    mainLayout.addWidget(toggleButton, 0, 0, 1, 3, Qt.AlignmentFlag.AlignCenter)
+    mainLayout.addWidget(toggleButton, 0, 0, 1, 3, Qt.AlignmentFlag.AlignHCenter)
     mainLayout.addWidget(contentArea, 1, 0, 1, 3)
     self.setLayout(mainLayout)
 
-    contentArea.setLayout(layout)
-    collapsedHeight = self.sizeHint().height() - contentArea.maximumHeight()
+    if not addScrollbars:
+      contentArea.setLayout(layout)
+    else:
+      widget = QWidget(self)
+      widget.setLayout(layout)
+      contentArea.setWidgetResizable(True)
+      contentArea.setWidget(widget)
+    self._collapseHeight = self.sizeHint().height() - contentArea.maximumHeight()
     contentHeight = layout.sizeHint().height()
-    toggleAnimation = QParallelAnimationGroup()
+    self._toggleAnimation = toggleAnimation = QParallelAnimationGroup()
     toggleAnimation.addAnimation(QPropertyAnimation(self, b"minimumHeight"))
     toggleAnimation.addAnimation(QPropertyAnimation(self, b"maximumHeight"))
     toggleAnimation.addAnimation(QPropertyAnimation(contentArea, b"maximumHeight"))
     for i in range(toggleAnimation.animationCount() - 1):
       spoilerAnimation = toggleAnimation.animationAt(i)
       spoilerAnimation.setDuration(animationDuration)
-      spoilerAnimation.setStartValue(collapsedHeight)
-      spoilerAnimation.setEndValue(collapsedHeight + contentHeight)
+      spoilerAnimation.setStartValue(self._collapseHeight)
+      spoilerAnimation.setEndValue(self._collapseHeight + contentHeight)
     contentAnimation = toggleAnimation.animationAt(toggleAnimation.animationCount() - 1)
     contentAnimation.setDuration(animationDuration)
     contentAnimation.setStartValue(0)
     contentAnimation.setEndValue(contentHeight)
 
-    def start_animation(checked):
-      arrow_type = Qt.DownArrow if checked else Qt.RightArrow
-      direction = QAbstractAnimation.Forward if checked else QAbstractAnimation.Backward
-      toggleButton.setArrowType(arrow_type)
+    def startAnimation(checked):
+      arrowType = Qt.ArrowType.DownArrow if checked else Qt.ArrowType.RightArrow
+      direction = QAbstractAnimation.Direction.Forward if checked else QAbstractAnimation.Direction.Backward
+      toggleButton.setArrowType(arrowType)
       toggleAnimation.setDirection(direction)
       toggleAnimation.start()
-    toggleButton.clicked.connect(start_animation)
+    toggleButton.clicked.connect(startAnimation)
+
+  def refresh(self, availableHeight):
+    layout = self._contentArea.layout()
+    height = layout.sizeHint().height() if layout is not None else self._contentArea.widget().sizeHint().height() + 5
+    contentHeight = min(height, availableHeight - self._collapseHeight - 10)
+    if self._contentArea.maximumHeight():
+      self._contentArea.setMaximumHeight(contentHeight)
+      self.setMinimumHeight(self._collapseHeight + contentHeight)
+      self.setMaximumHeight(self._collapseHeight + contentHeight)
+    for i in range(self._toggleAnimation.animationCount() - 1):
+      self._toggleAnimation.animationAt(i).setEndValue(self._collapseHeight + contentHeight)
+    self._toggleAnimation.animationAt(self._toggleAnimation.animationCount() - 1).setEndValue(contentHeight)
+
+
+class _InteractiveLabelCircle(QLabel):
+  circleSelected = pyqtSignal(bool)
+
+  def __init__(self, width, height):
+    super().__init__()
+    self._width = width
+    self._height = height
+    self._center = None
+    self._currentPosition = None
+    self._radius = None
+    self._size = None
+    self._tooltipShown = False
+    self.setMouseTracking(True)
+
+  def mousePressEvent(self, evt):
+    if self._center is None or self._radius is not None:
+      self._center = evt.pos()
+      self._radius = None
+      self._currentPosition = None
+      self.circleSelected.emit(False)
+    else:
+      self._radius = QLine(self._center, evt.pos())
+      self.circleSelected.emit(True)
+    self.update()
+
+  def mouseReleaseEvent(self, evt):
+    if self._radius is not None and not self._tooltipShown:
+      QToolTip.showText(evt.globalPosition() if PYQT6 else evt.globalPos(), "If you aren't satisfied with the selection, click again.", self, self.rect(), 5000)
+      self._tooltipShown = True
+
+  def mouseMoveEvent(self, evt):
+    self._currentPosition = evt.pos()
+    self.update()
+
+  def enterEvent(self, evt):
+    QApplication.setOverrideCursor(Qt.CursorShape.CrossCursor)
+
+  def leaveEvent(self, evt):
+    QApplication.restoreOverrideCursor()
+    self._currentPosition = None
+    self.update()
+
+  def paintEvent(self, evt):
+    super().paintEvent(evt)
+    if self._currentPosition is None and self._center is None:
+      return
+    qp = QPainter()
+    qp.begin(self)
+    if self._center is not None:
+      qp.setBrush(QColor(255, 0, 0))
+      qp.setPen(Qt.PenStyle.NoPen)
+      radius = self._radius if self._radius is not None else QLine(self._center, self._currentPosition) if self._currentPosition is not None else None
+      qp.drawEllipse(self._center, 2, 2)
+      if radius is not None:
+        radius = math.sqrt(radius.dx() * radius.dx() + radius.dy() * radius.dy())
+        qp.setBrush(Qt.BrushStyle.NoBrush)
+        qp.setPen(QColor(0, 0, 255))
+        qp.drawEllipse(self._center, radius, radius)
+    qp.end()
+
+  def resizeEvent(self, evt):
+    super().resizeEvent(evt)
+    self._size = self.size()
+
+  def getInfo(self):
+    if self._center is None or self._radius is None:
+      return None, None
+    if self._size.height() != self._height or self._size.width() != self._width:
+      center = transformCoordinates(QRectF(QPointF(0, 0), QSizeF(self._size)), QRectF(QPointF(0, 0), QSizeF(self._width, self._height)), self._center)
+      radius = transformCoordinates(QRectF(QPointF(0, 0), QSizeF(self._size)), QRectF(QPointF(0, 0), QSizeF(self._width, self._height)), self._radius)
+    else:
+      center = self._center
+      radius = self._radius
+    return center, int(math.sqrt(radius.dx() * radius.dx() + radius.dy() * radius.dy()))
+
+
+def getCircle(frame, title, backBtnCb=None):
+  height, width, _ = frame.shape
+
+  layout = QVBoxLayout()
+
+  video = _InteractiveLabelCircle(width, height)
+  layout.addWidget(video, alignment=Qt.AlignmentFlag.AlignCenter, stretch=1)
+  if backBtnCb is not None:
+    buttons = (("Cancel", backBtnCb, True), ("Ok", None, True, video.circleSelected))
+  else:
+    buttons = (("Ok", None, True, video.circleSelected),)
+  showBlockingPage(layout, title=title, buttons=buttons, labelInfo=(frame, video))
+  return video.getInfo()
+
+
+class _CollapseButton(QToolButton):
+  def enterEvent(self, evt):
+    QApplication.setOverrideCursor(Qt.CursorShape.ArrowCursor)
+    super().enterEvent(evt)
+
+  def leaveEvent(self, evt):
+    QApplication.restoreOverrideCursor()
+    super().leaveEvent(evt)
+
+
+class CollapsibleSplitter(QSplitter):
+  def __init__(self, *args, **kwargs):
+    super().__init__(*args, **kwargs)
+    self.setHandleWidth(12)
+    self._lastState = None
+
+  def _collapseButtonClicked(self):
+    self.setCollapsible(0, True)
+    leftWidget = self.widget(0)
+    orientation = self.orientation()
+    if all(self.sizes()):
+      self._lastState = self.saveState()
+      self._collapseButton.setArrowType(Qt.ArrowType.RightArrow if orientation == Qt.Orientation.Horizontal else Qt.ArrowType.DownArrow)
+      self.setSizes([0, 1])
+    else:
+      self._collapseButton.setArrowType(Qt.ArrowType.LeftArrow if orientation == Qt.Orientation.Horizontal else Qt.ArrowType.UpArrow)
+      self.setSizes([1, 1])
+      if self._lastState is not None:
+        self.restoreState(self._lastState)
+        self._lastState = None
+    self.setCollapsible(0, False)
+    self.splitterMoved.connect(self._splitterMoved)
+
+  def _splitterMoved(self, pos, idx):
+    assert idx == 1
+    orientation = self.orientation()
+    if pos and self._lastState is not None:
+      self._collapseButton.setArrowType(Qt.ArrowType.LeftArrow if orientation == Qt.Orientation.Horizontal else Qt.ArrowType.UpArrow)
+      self._lastState = None
+
+  def createHandle(self):
+    count = self.count()
+    orientation = self.orientation()
+    handle = QSplitterHandle(orientation, self)
+
+    layout = QVBoxLayout() if orientation == Qt.Orientation.Horizontal else QHBoxLayout()
+    layout.setContentsMargins(0, 0, 0, 0)
+
+    self._collapseButton = _CollapseButton()
+    self._collapseButton.setArrowType(Qt.ArrowType.LeftArrow if orientation == Qt.Orientation.Horizontal else Qt.ArrowType.UpArrow)
+    self._collapseButton.clicked.connect(self._collapseButtonClicked)
+    layout.addWidget(self._collapseButton)
+
+    handle.setLayout(layout)
+    return handle
