@@ -21,10 +21,7 @@ import json
 import subprocess
 import glob
 
-try:
-  from PyQt6.QtWidgets import QApplication
-except ImportError:
-  from PyQt5.QtWidgets import QApplication
+from PyQt5.QtWidgets import QApplication
 
 from zebrazoom.code.vars import getGlobalVariables
 globalVariables = getGlobalVariables()
@@ -33,6 +30,9 @@ output = 0
 
 # Does the tracking and then the extraction of parameters
 def getParametersForWell(videoPath,background,wellNumber,wellPositions,output,previouslyAcquiredTrackingDataForDebug,hyperparameters, videoName, dlModel):
+  if QApplication.instance() is None:
+    from zebrazoom.GUIAllPy import PlainApplication
+    app = PlainApplication(sys.argv)
   if hyperparameters["debugPauseBetweenTrackAndParamExtract"] == "noDebug":
     # Normal execution process
     trackingData = tracking(videoPath,background,wellNumber,wellPositions,hyperparameters, videoName, dlModel)
@@ -54,17 +54,6 @@ def getParametersForWell(videoPath,background,wellNumber,wellPositions,output,pr
     output.put([wellNumber,parameters,[]])
 
 
-# Getting parameters
-if len(sys.argv) > 2:
-  pathToVideo = sys.argv[1]
-  videoName   = sys.argv[2]
-  videoExt    = sys.argv[3] # Ext means extension (avi, mp4, etc...)
-  configFile  = sys.argv[4]
-  argv        = sys.argv
-else:
-  configFile  = ""
-
-
 def mainZZ(pathToVideo, videoName, videoExt, configFile, argv):
   
   videoNameWithExt = videoName + '.' + videoExt
@@ -114,8 +103,9 @@ def mainZZ(pathToVideo, videoName, videoExt, configFile, argv):
   
   # Launching GUI algoFollower if necessary
   if hyperparameters["popUpAlgoFollow"]:
-    popUpAlgoFollow.initialise()
-    popUpAlgoFollow.prepend("starting ZebraZoom analysis on " + videoName)
+    popUpAlgoFollow.createTraceFile("starting ZebraZoom analysis on " + videoName)
+    p = Process(target=popUpAlgoFollow.initialise)
+    p.start()
 
   if hyperparameters["debugPauseBetweenTrackAndParamExtract"] == "justExtractParamFromPreviousTrackData":
     # Reloading previously extracted tracking data if debugging option selected
@@ -184,6 +174,17 @@ def mainZZ(pathToVideo, videoName, videoExt, configFile, argv):
         pickle.dump(wellPositions, outfile2)
         outfile2.close()
     outfile.close()
+    app = QApplication.instance()
+    if hasattr(app, "wellPositions"):
+      if wellPositions is None:
+        return
+      app.wellPositions[:] = [(position['topLeftX'], position['topLeftY'], position['lengthX'], position['lengthY'])
+                              for idx, position in enumerate(wellPositions)]
+      if hyperparameters["wellsAreRectangles"] or len(hyperparameters["oneWellManuallyChosenTopLeft"]) or int(hyperparameters["multipleROIsDefinedDuringExecution"]) or hyperparameters["noWellDetection"] or hyperparameters["groupOfMultipleSameSizeAndShapeEquallySpacedWells"]:
+        app.wellShape = 'rectangle'
+      else:
+        app.wellShape = 'circle'
+
   if int(hyperparameters["exitAfterWellsDetection"]):
     print("exitAfterWellsDetection")
     if hyperparameters["popUpAlgoFollow"]:
@@ -205,6 +206,9 @@ def mainZZ(pathToVideo, videoName, videoExt, configFile, argv):
       pickle.dump(background, outfile)
       cv2.imwrite(os.path.join(outputFolderVideo, 'background.png'), background)
     outfile.close()
+    app = QApplication.instance()
+    if hasattr(app, "background"):
+      app.background = background
   if hyperparameters["exitAfterBackgroundExtraction"]:
     print("exitAfterBackgroundExtraction")
     raise ValueError
@@ -278,8 +282,20 @@ def mainZZ(pathToVideo, videoName, videoExt, configFile, argv):
         infoFrame = createValidationVideo(os.path.join(pathToVideo, videoNameWithExt), superStruct, hyperparameters)
     
     # Various post-processing options depending on configuration file choices
-    dataPostProcessing(outputFolderVideo, superStruct, hyperparameters, videoName, videoExt)
+    superStruct = dataPostProcessing(outputFolderVideo, superStruct, hyperparameters, videoName, videoExt)
+    
+    path = os.path.join(os.path.join(hyperparameters["outputFolder"], hyperparameters["videoName"]), 'results_' + hyperparameters["videoName"] + '.txt')
+    print("createSuperStruct:", path)
+    with open(path, 'w') as outfile:
+      json.dump(superStruct, outfile)
+    if hyperparameters["saveSuperStructToMatlab"]:
+      from scipy.io import savemat
+      matlabPath = os.path.join(os.path.join(hyperparameters["outputFolder"], hyperparameters["videoName"]), 'results_' + hyperparameters["videoName"] + '.mat')
+      videoDataResults2 = {}
+      videoDataResults2['videoDataResults'] = superStruct
+      savemat(matlabPath, videoDataResults2)
   
+    
   try:
     with open(os.path.join(os.path.join(hyperparameters["outputFolder"], hyperparameters["videoName"]), 'ZebraZoomVersionUsed.txt'), 'w') as fp:
       subprocess.run(["pip", "show",  "zebrazoom"], stdout=fp)
